@@ -156,7 +156,8 @@ class DrawBotContext(BaseContext):
     # Public callbacks.
 
     def setSize(self, width, height=None):
-        # Same as setSize?
+        width = upt(width)
+        height = upt(height)
         return self.b.size(width, height=height)
 
     def newPage(self, w=None, h=None, doc=None, **kwargs):
@@ -164,8 +165,7 @@ class DrawBotContext(BaseContext):
         if no arguments are provided.
 
         >>> from pagebot.toolbox.units import px
-        >>> from pagebot import getContext
-        >>> context = getContext()
+        >>> context = DrawBotContext()
         >>> context.newPage(pt(100), pt(100))
         >>> context.newPage(100, 100)
         """
